@@ -20,7 +20,7 @@ ImageBin::ImageBin ()
 	largeur = 0;
 	hauteur = 0;
 	nomLogique = wxString();
-	image = NULL;
+	image = 0;
 }
 
 /***************************/
@@ -140,6 +140,8 @@ ImageBin::ImageBin (wxString p_wNomLogique, int p_iLargeur, int p_iHauteur)
 	image = new Bin [l_iTaille];
 
 }
+
+
 /**************************************/
 /* Recherche de la Hauteur de l'Image */
 /**************************************/
@@ -184,7 +186,10 @@ Bin * ImageBin::ChercherImage ()
 
 ImageBin::~ImageBin ( void )
 {
-	delete [] image;
+	if (image!=0)
+		{
+		 delete [] image;
+		}
 }
 
 /*****************************/
@@ -252,6 +257,7 @@ for (int i=0; i<(largeur*hauteur);  i++)
 	{
 	 image [i] = 1 - image [i];
 	}
+return(1);
 }
 
 
@@ -370,7 +376,7 @@ for (i = 0 + p_pMasqueBin -> x0;
 		     }
 		    }
 		}
-	     l_TableauDestination [j*largeur + i ] = el;
+	     l_TableauDestination [(j + p_pMasqueBin->y0)*largeur + (i + p_pMasqueBin -> x0)] = el;
 	    }
 return (l_pDestination);
 }
@@ -425,8 +431,132 @@ for (i = 0 + p_pMasqueBin -> x0;
 		     }
 		    }
 		}
-	     l_TableauDestination [j*largeur + i ] = el;
+	     l_TableauDestination [(j + p_pMasqueBin->y0)*largeur + (i + p_pMasqueBin -> x0)] = el;
 	    }
 return (l_pDestination);
 }
 
+/*****************************************************/
+/* Ouverture d'une image binaire                     */
+/*****************************************************/
+ImageBin * ImageBin::OuvertureBin(wxString p_wNomDestination, MasqueBin *p_pMasqueBin)
+{
+// 1 Erosion
+
+wxString l_NomTemp = wxString("Tmp");
+ImageBin *l_ImageBinErosion = this->ErosionBin(l_NomTemp, p_pMasqueBin);
+
+// 2 DIlatation
+ImageBin *l_pDestination = l_ImageBinErosion->DilatationBin(p_wNomDestination, p_pMasqueBin);
+
+delete l_ImageBinErosion;
+return (l_pDestination);
+}
+
+/*****************************************************/
+/* Fermeture d'une image binaire                     */
+/*****************************************************/
+ImageBin * ImageBin::FermetureBin(wxString p_wNomDestination, MasqueBin *p_pMasqueBin)
+{
+// 1 Dilatation
+
+wxString l_NomTemp = wxString("Tmp");
+ImageBin *l_ImageBinDilatation = this->DilatationBin(l_NomTemp, p_pMasqueBin);
+
+// 2 Erosion
+ImageBin *l_pDestination = l_ImageBinDilatation->ErosionBin(p_wNomDestination, p_pMasqueBin);
+
+delete l_ImageBinDilatation;
+return (l_pDestination);
+}
+/***********************************/
+/* Coloriage d'un Objet de l'Image */
+/***********************************/
+int ImageBin::Coloriage (int x, int y)
+{
+	static int compteur =0;
+
+	
+	if (image [y*largeur + x] == 0)
+	{
+		return 0;
+	}
+	else
+	{
+		compteur++;
+		image [y*largeur + x] = 0;
+
+		if ((compteur / largeur) % 2)
+		{
+			if (x+1 < largeur)
+				this->Coloriage (x+1, y);
+
+			if (x-1 >= 0)
+				this->Coloriage (x-1, y);
+
+			if (y+1 < hauteur)
+				this->Coloriage (x, y+1);
+
+			if (y-1 >= 0)
+				this->Coloriage (x, y-1);
+		}
+		else
+		{
+			if (y+1 < hauteur)
+				this->Coloriage (x, y+1);
+
+			if (y-1 >= 0)
+				this->Coloriage (x, y-1);
+			
+			if (x+1 < largeur)
+				this->Coloriage (x+1, y);
+
+			if (x-1 >= 0)
+				this->Coloriage (x-1, y);
+		}
+
+		if ((x-1 >= 0) && (y-1 >= 0))
+		{
+			this->Coloriage (x-1, y-1);
+		}
+
+		if ((x+1 > largeur) && (y-1 >= 0))
+		{
+			this->Coloriage (x+1, y-1);
+		}
+
+		if ((x+1 > largeur) && (y+1 > hauteur))
+		{
+			this->Coloriage (x+1, y+1);
+		}
+
+		if ((x-1 >= 0) && (y+1 > hauteur))
+		{
+			this->Coloriage (x-1, y+1);
+		}
+		return compteur;
+	}
+}
+
+/***********************************/
+/* Comptage du Nombre de Region    */
+/***********************************/
+int ImageBin::NombreRegion(void)
+{
+int
+ l_iNombreRegion=0;
+
+for (long int i=0; i<hauteur; i++)
+	{
+	 for (long int j=0; j<largeur; j++)
+		{
+		 if (image [i*largeur + j] != 0)
+			{
+			 this->Coloriage(j,i);
+			 l_iNombreRegion++;
+			}
+		}
+	}
+ return(l_iNombreRegion);
+
+}
