@@ -58,6 +58,10 @@ public :
 	ImageBin *Diviser (wxString p_wNomDestination);
 	ImageBin *ErosionBin(wxString p_wNomDestination, MasqueBin * p_pMasqueBin);
 	ImageBin *DilatationBin(wxString p_wNomDestination, MasqueBin * p_pMasqueBin);
+	ImageBin *OuvertureBin(wxString p_wNomDestination, MasqueBin * p_pMasqueBin);
+	ImageBin *FermetureBin(wxString p_wNomDestination, MasqueBin * p_pMasqueBin);
+	int Coloriage (int p_iPositionX, int p_iPositionY);
+	int NombreRegion(void);
 };
 
 
