@@ -212,6 +212,7 @@ for (int i=0; i<(largeur*hauteur);  i++)
 	{
 	 image [i] = - image [i];
 	}
+return(1);
 }
 
 
@@ -404,8 +405,7 @@ for (i = 0 + p_MasqueConvolution -> x0;
 		    somme += l_Tableau[(j+y)*largeur+i+x] *
 p_MasqueConvolution->tableau[y*(p_MasqueConvolution->largeur)+ x];
 		}
-		//printf("%g %g\n",somme,p_MasqueConvolution -> diviseur);
-	     l_TableauDestination [j*largeur + i ] = somme / p_MasqueConvolution -> diviseur;
+	     l_TableauDestination [(j + p_MasqueConvolution->y0)*largeur + (i + p_MasqueConvolution -> x0)] = somme / p_MasqueConvolution -> diviseur;
 	    }	
 	
 	return(Destination);
