@@ -56,12 +56,15 @@ public :
 //	Methodes
 	double ValeurMax();
 	double ValeurMin();
+	double ValeurMoyenne();
 	
 	wxBitmap * VisualiserDouble ();
 	int Inverse ();
 ImageDouble *ImageDouble::Convoluer(wxString p_wNomDestination, MasqueDouble
 * p_MasqueConvolution);	
 	ImageDouble *Diviser (wxString p_wNomDestination);
+	/* recherche d'un max par rapport a un seuil dans une fenetre */
+	ImageDouble *MaxFenetreSeuil (wxString p_wNomDestination, int p_iTaille, Double l_pSeuil);
 };
 
 
