@@ -225,6 +225,7 @@ for (int i=0; i<(largeur*hauteur);  i++)
 	{
 	 image [i] = 255 - image [i];
 	}
+return(1);
 }
 
 /*
@@ -339,7 +340,7 @@ for (i = 0 + p_MasqueConvolution -> x0;
 		    somme += l_Tableau[(j+y)*largeur+i+x] *
 p_MasqueConvolution->tableau[y*(p_MasqueConvolution->largeur)+ x];
 		}
-	     l_TableauDestination [j*largeur + i ] = somme / p_MasqueConvolution -> diviseur;
+	     l_TableauDestination [(j + p_MasqueConvolution->y0)*largeur + (i + p_MasqueConvolution -> x0)] = somme / p_MasqueConvolution -> diviseur;
 	    }	
 	
 	return(Destination);
