@@ -131,17 +131,23 @@ bool MyApp::OnInit(void)
   l_wMenuFichier -> Append(TAI_QUIT, "F&ermer", "Fin de l'application");
   
   // Menu Operation 256
+  l_wMenuOperation256 ->Append(TAI_SUPPRIMER_256, "&Supprimer", "Suppresion d'une image");
   l_wMenuOperation256 ->Append(TAI_INVERSER_256, "&Inverser", "Inversion de l'image");
   l_wMenuOperation256 ->Append(TAI_DIVISER_256, "&Diviser", "Division de la taille de l'image");
   l_wMenuOperation256 ->Append(TAI_SEUILLER_256, "&Seuiller", "Seuillage de l'image pour obtenir une image binaire");
   l_wMenuOperation256 ->Append(TAI_CONVOLUER_256, "&Convoluer", "Convolution de l'image pour obtenir une image double");
 
   // Menu Operation Bin
+  l_wMenuOperationBin ->Append(TAI_SUPPRIMER_BIN, "&Supprimer", "Suppresion d'une image");
   l_wMenuOperationBin ->Append(TAI_INVERSER_BIN, "&Inverser", "Inversion de l'image binaire");
-l_wMenuOperationBin ->Append(TAI_EROSION_BIN, "&Erosion", "Erosion de l'image binaire");
-l_wMenuOperationBin ->Append(TAI_DILATATION_BIN, "&Dilatation", "Dilatation de l'image binaire");
-
+  l_wMenuOperationBin ->Append(TAI_EROSION_BIN, "&Erosion", "Erosion de l'image binaire");
+  l_wMenuOperationBin ->Append(TAI_DILATATION_BIN, "&Dilatation", "Dilatation de l'image binaire");
+  l_wMenuOperationBin ->Append(TAI_OUVERTURE_BIN, "&Ouverture", "Ouverture de l'image binaire");
+  l_wMenuOperationBin ->Append(TAI_FERMETURE_BIN, "&Fermeture", "Fermeture de l'image binaire");
+  l_wMenuOperationBin ->Append(TAI_NBREGION_BIN, "&Nombre Region", "Nombre de Region de l'image");
+  
   // Menu operation Double
+  l_wMenuOperationDouble ->Append(TAI_SUPPRIMER_DOUBLE, "&Supprimer", "Suppresion d'une image");
   l_wMenuOperationDouble ->Append(TAI_CONVERTIR_IMAGE_GRAY, "&Convertir 256", "Conversion de l'image en 256 gris");
   l_wMenuOperationDouble ->Append(TAI_CONVERTIR_IMAGE_GRAY_MIN_MAX, "&Convertir 256 Min-Max",
   "Conversion de l'image en 256 gris entre niveau Min et Max");
@@ -315,19 +321,25 @@ BEGIN_EVENT_TABLE(MyFrame, wxFrame)
     EVT_MENU(TAI_DIVISER_256,   MyFrame::OnDiviser256)
     EVT_MENU(TAI_SEUILLER_256,   MyFrame::OnSeuiller256)
     EVT_MENU(TAI_CONVOLUER_256,   MyFrame::OnConvoluer256)
+    EVT_MENU(TAI_SUPPRIMER_256,   MyFrame::OnSupprimer256)
     
 // Menu operation-Bin
     EVT_MENU(TAI_INVERSER_BIN,   MyFrame::OnInverserBin)
     EVT_MENU(TAI_EROSION_BIN,   MyFrame::OnErosionBin)
-    EVT_MENU(TAI_DILATATION_BIN,   MyFrame::OnDilatationBin)   
-
+    EVT_MENU(TAI_DILATATION_BIN,   MyFrame::OnDilatationBin)
+    EVT_MENU(TAI_OUVERTURE_BIN,   MyFrame::OnOuvertureBin)
+    EVT_MENU(TAI_FERMETURE_BIN,   MyFrame::OnFermetureBin)        	
+    EVT_MENU(TAI_NBREGION_BIN,   MyFrame::OnNombreRegion) 
+    EVT_MENU(TAI_SUPPRIMER_BIN,   MyFrame::OnSupprimerBin)
+    
 // Menu Operation Double
     EVT_MENU(TAI_CONVERTIR_IMAGE_GRAY,   MyFrame::OnConvertirImageGray)
     EVT_MENU(TAI_CONVERTIR_IMAGE_GRAY_MIN_MAX,   MyFrame::OnConvertirImageGrayMinMax)
     EVT_MENU(TAI_AFFICHER_MIN_MAX,   MyFrame::OnImageDoubleAfficherMinMax)
     EVT_MENU(TAI_CONVOLUER_DOUBLE,   MyFrame::OnConvoluerImageDouble)
     EVT_MENU(TAI_SEUILLER_DOUBLE,   MyFrame::OnSeuillerDouble)
-
+    EVT_MENU(TAI_SUPPRIMER_DOUBLE,   MyFrame::OnSupprimerDouble)
+    
 // Menu aide
     EVT_MENU(TAI_ABOUT,     MyFrame::OnAbout)
     EVT_MENU(TAI_TEST,     MyFrame::OnTest)
@@ -477,6 +489,16 @@ g_InterfaceImageGray256.OnImage256(event);
 return;
 }
 
+//--------------------------------------
+// Detruit l'image gray 256 selectionnee
+//--------------------------------------
+
+void MyFrame::OnSupprimer256(wxCommandEvent& event)
+{
+g_InterfaceImageGray256.OnSupprimer256();
+return;
+}
+
 //----------------------------
 // Fonction Inverser image 256
 //----------------------------
@@ -578,7 +600,6 @@ return;
 void MyFrame::OnErosionBin(wxCommandEvent& WXUNUSED(event))
 {
 g_InterfaceImageBin.OnErosionBin();
-
 return;
 }
 
@@ -589,7 +610,45 @@ return;
 void MyFrame::OnDilatationBin(wxCommandEvent& WXUNUSED(event))
 {
 g_InterfaceImageBin.OnDilatationBin();
+return;
+}
 
+//--------------------------
+// Ouverture d'une image bin 
+//--------------------------
+
+void MyFrame::OnOuvertureBin(wxCommandEvent& WXUNUSED(event))
+{
+g_InterfaceImageBin.OnOuvertureBin();
+return;
+}
+
+//--------------------------
+// Fermeture d'une image bin 
+//--------------------------
+
+void MyFrame::OnFermetureBin(wxCommandEvent& WXUNUSED(event))
+{
+g_InterfaceImageBin.OnFermetureBin();
+return;
+}
+
+//-----------------------
+// Calcul Nombre Region 
+//-----------------------
+
+void MyFrame::OnNombreRegion(wxCommandEvent& WXUNUSED(event))
+{
+g_InterfaceImageBin.OnNombreRegion();
+return;
+}
+//---------------------------------
+// Detruit l'image Bin selectionnee
+//---------------------------------
+
+void MyFrame::OnSupprimerBin(wxCommandEvent& event)
+{
+g_InterfaceImageBin.OnSupprimerBin();
 return;
 }
 
@@ -813,6 +872,15 @@ return;
 
 }
 
+//--------------------------------------
+// Detruit l'image Double selectionnee
+//--------------------------------------
+
+void MyFrame::OnSupprimerDouble(wxCommandEvent& event)
+{
+g_InterfaceImageDouble.OnSupprimerDouble();
+return;
+}
 //----------------------------------
 // Fonction Seuillage image Double
 //----------------------------------
