@@ -60,12 +60,17 @@ class MyFrame: public wxFrame
     void OnDiviser256(wxCommandEvent& event);
     void OnSeuiller256(wxCommandEvent& event);
     void OnConvoluer256(wxCommandEvent& event);
+    void OnSupprimer256(wxCommandEvent& event);
     
     // Methode Image Bin
     void OnImageBin(wxCommandEvent& event);
     void OnInverserBin(wxCommandEvent& event);
     void OnErosionBin(wxCommandEvent& event);
     void OnDilatationBin(wxCommandEvent& event);
+    void OnOuvertureBin(wxCommandEvent& event);
+    void OnFermetureBin(wxCommandEvent& event);
+    void OnNombreRegion(wxCommandEvent& event);
+    void OnSupprimerBin(wxCommandEvent& event);
     
     // Methode Image Double
     void OnImageDouble(wxCommandEvent& event);
@@ -74,6 +79,7 @@ class MyFrame: public wxFrame
     void OnImageDoubleAfficherMinMax(wxCommandEvent& event);
     void OnConvoluerImageDouble(wxCommandEvent& event);
     void OnSeuillerDouble(wxCommandEvent& event);
+    void OnSupprimerDouble(wxCommandEvent& event);
     
     // Methode Masque
     void OnOuvrirMasqueDouble(wxCommandEvent& event);
@@ -110,11 +116,16 @@ DECLARE_EVENT_TABLE()
 #define TAI_DIVISER_256				201
 #define TAI_SEUILLER_256			202
 #define TAI_CONVOLUER_256			203
+#define TAI_SUPPRIMER_256			204
 
 // Menu Operation Bin
 #define TAI_INVERSER_BIN			300
 #define TAI_EROSION_BIN				301
 #define TAI_DILATATION_BIN			302
+#define TAI_OUVERTURE_BIN			303
+#define TAI_FERMETURE_BIN			304
+#define TAI_NBREGION_BIN			305
+#define TAI_SUPPRIMER_BIN			306
 
 // Menu Operation Double 
 #define TAI_CONVERTIR_IMAGE_GRAY		400
@@ -122,6 +133,7 @@ DECLARE_EVENT_TABLE()
 #define TAI_AFFICHER_MIN_MAX			402
 #define TAI_CONVOLUER_DOUBLE			403
 #define TAI_SEUILLER_DOUBLE			404
+#define TAI_SUPPRIMER_DOUBLE			405
 
 // Menu About
 #define TAI_ABOUT      				501
