@@ -300,7 +300,7 @@ ImageBin *l_ImageBinDestination = new ImageBin(l_pImageSourceBin);
 wxString l_wNomMasqueBin = wxString("NoyauBin");
 l_MasqueBin = g_InterfaceMasqueBin.ChercherMasqueBin(l_wNomMasqueBin);
 
-// Inversion de l'Image
+// Erosion de l'Image
 l_ImageBinDestination = l_pImageSourceBin->ErosionBin(l_wNomImageDestination, l_MasqueBin);
 
 // Insertion dans la Liste
@@ -367,7 +367,7 @@ ImageBin *l_ImageBinDestination = new ImageBin(l_pImageSourceBin);
 wxString l_wNomMasqueBin = wxString("NoyauBin");
 l_MasqueBin = g_InterfaceMasqueBin.ChercherMasqueBin(l_wNomMasqueBin);
 
-// Inversion de l'Image
+// Dilatation de l'Image
 l_ImageBinDestination = l_pImageSourceBin->DilatationBin(l_wNomImageDestination, l_MasqueBin);
 
 // Insertion dans la Liste
@@ -389,6 +389,135 @@ if (l_iStatus != -1)
 wxEndBusyCursor();
 return;
 }
+
+//-----------------------
+// Fonction Ouverture Bin
+//-----------------------
+
+void InterfaceImageBin::OnOuvertureBin()
+{
+ImageBin
+	*l_pImageSourceBin;
+int
+	l_iStatus;
+MasqueBin
+	*l_MasqueBin;
+	
+// Lecture Nom Logique de L'image Source
+wxString l_wNomImage = wxGetTextFromUser("Entrez le nom de l'image source: ", "Nom de l'image", "");
+
+l_pImageSourceBin = ChercherImageBin(l_wNomImage);
+
+if (l_pImageSourceBin == 0)
+	{
+	 return;
+	}
+
+// Lecture Nom Logique de L'image
+wxString l_wNomImageDestination = wxGetTextFromUser("Entrez le nom de l'image destination: ", "Nom de l'image", "");
+
+// Debut Attente
+wxBeginBusyCursor();
+
+// Recherche si l'image Existe de deja
+if (g_wListeImageBin.Find(l_wNomImageDestination)!= 0)
+	{	
+	(void)wxMessageBox("Image Existante",
+            "Erreur", wxOK);
+	 return;
+	}
+	
+
+// Recuperation du masque bin
+wxString l_wNomMasqueBin = wxString("NoyauBin");
+l_MasqueBin = g_InterfaceMasqueBin.ChercherMasqueBin(l_wNomMasqueBin);
+
+// Ouverture de l'Image
+ImageBin * l_ImageBinDestination = l_pImageSourceBin->OuvertureBin(l_wNomImageDestination, l_MasqueBin);
+// Insertion dans la Liste
+l_iStatus = AjouterImageBin(l_wNomImageDestination.GetData(), l_ImageBinDestination);
+// Affichage
+if (l_iStatus != -1)
+	{
+	 if (g_Bitmap) //liberation de la memoire
+		{
+		 delete g_Bitmap;
+		}
+
+	 g_Bitmap = l_ImageBinDestination->VisualiserBin();
+
+	 // Mise a jour de l'affichage
+	 (g_Frame->canvas)->Refresh();
+	}
+// Fin attente
+wxEndBusyCursor();
+return;
+}
+
+//-----------------------
+// Fonction Fermeture Bin
+//-----------------------
+
+void InterfaceImageBin::OnFermetureBin()
+{
+ImageBin
+	*l_pImageSourceBin;
+int
+	l_iStatus;
+MasqueBin
+	*l_MasqueBin;
+	
+// Lecture Nom Logique de L'image Source
+wxString l_wNomImage = wxGetTextFromUser("Entrez le nom de l'image source: ", "Nom de l'image", "");
+
+l_pImageSourceBin = ChercherImageBin(l_wNomImage);
+
+if (l_pImageSourceBin == 0)
+	{
+	 return;
+	}
+
+// Lecture Nom Logique de L'image
+wxString l_wNomImageDestination = wxGetTextFromUser("Entrez le nom de l'image destination: ", "Nom de l'image", "");
+
+// Debut Attente
+wxBeginBusyCursor();
+
+// Recherche si l'image Existe de deja
+if (g_wListeImageBin.Find(l_wNomImageDestination)!= 0)
+	{	
+	(void)wxMessageBox("Image Existante",
+            "Erreur", wxOK);
+	 return;
+	}
+	
+
+// Recuperation du masque bin
+wxString l_wNomMasqueBin = wxString("NoyauBin");
+l_MasqueBin = g_InterfaceMasqueBin.ChercherMasqueBin(l_wNomMasqueBin);
+
+// Ouverture de l'Image
+ImageBin * l_ImageBinDestination = l_pImageSourceBin->FermetureBin(l_wNomImageDestination, l_MasqueBin);
+// Insertion dans la Liste
+l_iStatus = AjouterImageBin(l_wNomImageDestination.GetData(), l_ImageBinDestination);
+// Affichage
+if (l_iStatus != -1)
+	{
+	 if (g_Bitmap) //liberation de la memoire
+		{
+		 delete g_Bitmap;
+		}
+
+	 g_Bitmap = l_ImageBinDestination->VisualiserBin();
+
+	 // Mise a jour de l'affichage
+	 (g_Frame->canvas)->Refresh();
+	}
+// Fin attente
+wxEndBusyCursor();
+return;
+}
+
 //----------------------------------
 // Fonction Diviser taille image Bin
 //----------------------------------
@@ -438,3 +567,128 @@ wxEndBusyCursor();
 
 return;
 }
+
+//------------------------
+// Fonction Compte Region
+//------------------------
+
+void InterfaceImageBin::OnNombreRegion()
+{
+ImageBin 
+	*l_pImageSourceBin;
+int
+	l_iStatus;
+
+
+// Lecture Nom Logique de L'image Source
+wxString l_wNomImage = wxGetTextFromUser("Entrez le nom de l'image : ", "Nom de l'image", "");
+
+l_pImageSourceBin = ChercherImageBin(l_wNomImage);
+
+if (l_pImageSourceBin == 0)
+	{
+	 return;
+	}
+
+// Debut Attente
+wxBeginBusyCursor();
+
+ImageBin *CopyImage = new ImageBin(l_pImageSourceBin);
+
+// A changer quand wxString plus performant
+char l_zChaineTemporaire[40];
+snprintf(l_zChaineTemporaire,40,"%d",CopyImage->NombreRegion());
+// Fin attente
+wxEndBusyCursor();
+wxString l_wResultat = wxString("Nb Region: ")+ wxString(l_zChaineTemporaire);
+(void)wxMessageBox(wxString(l_wResultat), "Valeur", wxOK);
+delete CopyImage;
+return;
+}
+
+/***********************************************/
+/* Supprimer image dans la liste image Bin     */
+/***********************************************/
+
+void InterfaceImageBin::OnSupprimerBin()
+{
+int
+	l_iNbImage;
+
+
+// Selection de l'image a supprimer
+l_iNbImage=g_wListeImageBin.Number();
+if (l_iNbImage == 0)
+  {
+    wxMessageBox ("Il n'y a pas d'image", "Erreur", wxOK);
+    return;
+  }
+// Affichage des images disponibles
+
+wxString l_wxNomImage[l_iNbImage];
+char * l_zChoix[l_iNbImage];
+
+//wxNode *node = g_wListeMasqueDouble.First();
+wxNode *node = g_wListeImageBin.First();
+int l_iIndice=0;
+while (node)
+  {
+    l_wxNomImage[l_iIndice] = ((ImageBin *)node->Data())->ChercherNom();
+    // Destruction du menu
+    int l_iItemMenuDestruction = g_wMenuImageBin->FindItem(l_wxNomImage[l_iIndice]);
+    g_wMenuImageBin->Delete(l_iItemMenuDestruction);
+    l_zChoix[l_iIndice] = (char *)l_wxNomImage[l_iIndice].GetData();
+    l_iIndice++;
+    node = node->Next();
+  }
+
+wxString l_wxResultat = wxGetSingleChoice(wxString("Image"), wxString("Nom"), l_iNbImage, l_wxNomImage,
+  NULL,  -1, -1, true, 200, 200);
+
+// si aucun choix fin
+
+if (l_wxResultat.IsEmpty())
+	{
+	(void)wxMessageBox("Pas d'image selectionnee",
+            "Erreur", wxOK);
+	 // reconstruction du menu
+	 node = g_wListeImageBin.First();
+	 l_iIndice=0;
+	 while (node)
+	  {
+	    l_wxNomImage[l_iIndice] = ((ImageBin *)node->Data())->ChercherNom();
+	    // Reconstruction du menu
+	    g_wMenuImageBin -> Append(3 * BASELISTE + l_iIndice, l_wxNomImage[l_iIndice]);
+	    l_iIndice++;
+	    node = node->Next();
+	  }
+	 return;
+	}
+
+// recherche de l'image et destructions
+ImageBin * l_ImageBin;
+l_ImageBin = g_wListeImageBin.Find(l_wxResultat.GetData())->GetData();
+
+// Suppression de la liste des images
+if (!g_wListeImageBin.DeleteNode(g_wListeImageBin.Find(l_wxResultat.GetData())))
+	{
+	(void)wxMessageBox("PB de destruction d'image",
+            "Erreur", wxOK);
+	 return;
+	}
+// Reconstruction du Menu
+
+node = g_wListeImageBin.First();
+l_iIndice=0;
+while (node)
+  {
+    l_wxNomImage[l_iIndice] = ((ImageBin *)node->Data())->ChercherNom();
+    // Reconstruction du menu
+    g_wMenuImageBin -> Append(3 * BASELISTE + l_iIndice, l_wxNomImage[l_iIndice]);
+    l_iIndice++;
+    node = node->Next();
+  }
+g_NbImageBin--;
+return;
+}
+
