@@ -41,6 +41,10 @@ public :
 	void OnDiviserBin();
 	void OnErosionBin();
 	void OnDilatationBin();
+	void OnOuvertureBin();
+	void OnFermetureBin();
+	void OnNombreRegion();
+	void OnSupprimerBin();
 	wxBitmap * VisualiserBin (ImageBin *l_pImageBin);
 	int AjouterImageBin(wxString l_wNomImage, ImageBin * l_pImageBin);
 	ImageBin * ChercherImageBin(wxString l_wNomImage);
