@@ -214,6 +214,92 @@ wxEndBusyCursor();
 return;
 }
 
+/***********************************************/
+/* Supprimer image dans la liste image Double  */
+/***********************************************/
+
+void InterfaceImageDouble::OnSupprimerDouble()
+{
+int
+	l_iNbImage;
+
+
+// Selection de l'image a supprimer
+l_iNbImage=g_wListeImageDouble.Number();
+if (l_iNbImage == 0)
+  {
+    wxMessageBox ("Il n'y a pas d'image", "Erreur", wxOK);
+    return;
+  }
+// Affichage des images disponibles
+
+wxString l_wxNomImage[l_iNbImage];
+char * l_zChoix[l_iNbImage];
+
+//wxNode *node = g_wListeMasqueDouble.First();
+wxNode *node = g_wListeImageDouble.First();
+int l_iIndice=0;
+while (node)
+  {
+    l_wxNomImage[l_iIndice] = ((ImageDouble *)node->Data())->ChercherNom();
+    // Destruction du menu
+    int l_iItemMenuDestruction = g_wMenuImageDouble->FindItem(l_wxNomImage[l_iIndice]);
+    g_wMenuImageDouble->Delete(l_iItemMenuDestruction);
+    l_zChoix[l_iIndice] = (char *)l_wxNomImage[l_iIndice].GetData();
+    l_iIndice++;
+    node = node->Next();
+  }
+
+wxString l_wxResultat = wxGetSingleChoice(wxString("Image"), wxString("Nom"), l_iNbImage, l_wxNomImage,
+  NULL,  -1, -1, true, 200, 200);
+
+// si aucun choix fin
+
+if (l_wxResultat.IsEmpty())
+	{
+	(void)wxMessageBox("Pas d'image selectionnee",
+            "Erreur", wxOK);
+	 // reconstruction du menu
+	 node = g_wListeImageDouble.First();
+	 l_iIndice=0;
+	 while (node)
+	  {
+	    l_wxNomImage[l_iIndice] = ((ImageDouble *)node->Data())->ChercherNom();
+	    // Reconstruction du menu
+	    g_wMenuImageDouble -> Append(4 * BASELISTE + l_iIndice, l_wxNomImage[l_iIndice]);
+	    l_iIndice++;
+	    node = node->Next();
+	  }
+	 return;
+	}
+
+// recherche de l'image et destructions
+ImageDouble * l_ImageDouble;
+l_ImageDouble = g_wListeImageDouble.Find(l_wxResultat.GetData())->GetData();
+
+// Suppression de la liste des images
+if (!g_wListeImageDouble.DeleteNode(g_wListeImageDouble.Find(l_wxResultat.GetData())))
+	{
+	(void)wxMessageBox("PB de destruction d'image",
+            "Erreur", wxOK);
+	 return;
+	}
+// Reconstruction du Menu
+
+node = g_wListeImageDouble.First();
+l_iIndice=0;
+while (node)
+  {
+    l_wxNomImage[l_iIndice] = ((ImageDouble *)node->Data())->ChercherNom();
+    // Reconstruction du menu
+    g_wMenuImageDouble -> Append(4 * BASELISTE + l_iIndice, l_wxNomImage[l_iIndice]);
+    l_iIndice++;
+    node = node->Next();
+  }
+g_NbImageDouble--;
+return;
+}
+
 //-------------------------
 // Fonction Inverser Double
 //-------------------------
