@@ -98,6 +98,90 @@ g_NbImage256++;
 return(1);
 }
 
+/***********************************************/
+/* Supprimer image dans la liste image gray 256*/
+/***********************************************/
+
+void InterfaceImageGray256::OnSupprimer256()
+{
+int
+	l_iNbImage;
+
+// Selection de l'image a supprimer
+l_iNbImage=g_wListeImageGray256.Number();
+if (l_iNbImage == 0)
+  {
+    wxMessageBox ("Il n'y a pas d'image", "Erreur", wxOK);
+    return;
+  }
+// Affichage des images disponibles
+
+wxString l_wxNomImage[l_iNbImage];
+char * l_zChoix[l_iNbImage];
+
+//wxNode *node = g_wListeMasqueDouble.First();
+wxNode *node = g_wListeImageGray256.First();
+int l_iIndice=0;
+while (node)
+  {
+    l_wxNomImage[l_iIndice] = ((ImageGray256 *)node->Data())->ChercherNom();
+    // Destruction du menu
+    int l_iItemMenuDestruction = g_wMenuImage256->FindItem(l_wxNomImage[l_iIndice]);
+    g_wMenuImage256->Delete(l_iItemMenuDestruction);
+    l_zChoix[l_iIndice] = (char *)l_wxNomImage[l_iIndice].GetData();
+    l_iIndice++;
+    node = node->Next();
+  }
+
+wxString l_wxResultat = wxGetSingleChoice(wxString("Image"), wxString("Nom"), l_iNbImage, l_wxNomImage,
+  NULL,  -1, -1, true, 200, 200);
+
+// si aucun choix fin
+
+if (l_wxResultat.IsEmpty())
+	{
+	(void)wxMessageBox("Pas d'image selectionnee",
+            "Erreur", wxOK);
+	 // reconstruction du menu
+	 node = g_wListeImageGray256.First();
+	 l_iIndice=0;
+	 while (node)
+	  {
+	    l_wxNomImage[l_iIndice] = ((ImageGray256 *)node->Data())->ChercherNom();
+	    // Reconstruction du menu
+	    g_wMenuImage256 -> Append(2 * BASELISTE + l_iIndice, l_wxNomImage[l_iIndice]);
+	    l_iIndice++;
+	    node = node->Next();
+	  }
+	 return;
+	}
+
+// recherche de l'image et destructions
+ImageGray256 * l_ImageGray256;
+l_ImageGray256 = g_wListeImageGray256.Find(l_wxResultat.GetData())->GetData();
+
+// Suppression de la liste des images
+if (!g_wListeImageGray256.DeleteNode(g_wListeImageGray256.Find(l_wxResultat.GetData())))
+	{
+	(void)wxMessageBox("PB de destruction d'image",
+            "Erreur", wxOK);
+	 return;
+	}
+// Reconstruction du Menu
+
+node = g_wListeImageGray256.First();
+l_iIndice=0;
+while (node)
+  {
+    l_wxNomImage[l_iIndice] = ((ImageGray256 *)node->Data())->ChercherNom();
+    // Reconstruction du menu
+    g_wMenuImage256 -> Append(2 * BASELISTE + l_iIndice, l_wxNomImage[l_iIndice]);
+    l_iIndice++;
+    node = node->Next();
+  }
+g_NbImage256--;
+return;
+}
 /***************************/
 /* Ouvrir Fichier Gray 256 */
 /***************************/
